@@ -8,7 +8,6 @@ package Sub::Accessor::Small;
 use Carp             qw( carp croak );
 use Eval::TypeTiny   qw();
 use Exporter::Tiny   qw();
-use Hash::FieldHash  qw( fieldhash );
 use Scalar::Util     qw( blessed reftype );
 
 BEGIN {
@@ -20,8 +19,15 @@ BEGIN {
 		: sub(){0};
 };
 
+BEGIN {
+	*fieldhash =
+		eval { require Hash::FieldHash;               \&Hash::FieldHash::fieldhash               } ||
+		eval { require Hash::Util::FieldHash;         \&Hash::Util::FieldHash::fieldhash         } ||
+		do   { require Hash::Util::FieldHash::Compat; \&Hash::Util::FieldHash::Compat::fieldhash } ;;
+};
+
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.011';
+our $VERSION   = '0.012';
 our @ISA       = qw/ Exporter::Tiny /;
 
 fieldhash( our %FIELDS );
